@@ -23,7 +23,9 @@ int main(int argc, char **argv)
     }
 
     QProcess meinproc;
-    meinproc.start("meinproc5", QStringList() << "--check" << "--stdout" << arguments[1]);
+    meinproc.start("meinproc5",
+                   QStringList() << "--check"
+                                 << "--stdout" << arguments[1]);
     if (!meinproc.waitForStarted())
         return -2;
     if (!meinproc.waitForFinished())
